@@ -2,7 +2,7 @@ import re
 
 from prompt_toolkit.completion import Completer, Completion
 
-from .robotkeyword import parse_keyword
+from .robotkeyword import normalize_kw, parse_keyword
 from .styles import _get_style_completions
 
 
@@ -19,37 +19,13 @@ class CmdCompleter(Completer):
             self.display_metas[name] = display_meta
         self.cmd_repl = cmd_repl
 
-    def _get_argument_completions(self, completer, document):
-        """Using Cmd.py's completer to complete arguments."""
-        end_idx = document.cursor_position_col
-        line = document.current_line
-        if line[:end_idx].rfind(" ") >= 0:
-            begin_idx = line[:end_idx].rfind(" ") + 1
-        else:
-            begin_idx = 0
-        prefix = line[begin_idx:end_idx]
-
-        completions = completer(prefix, line, begin_idx, end_idx)
-        for comp in completions:
-            yield Completion(comp, begin_idx - end_idx, display=comp)
-
-    def _get_custom_completions(self, cmd_name, document):
-        completer = getattr(
-            self.cmd_repl,
-            "complete_{0}".format(cmd_name),
-            None,
-        )
-        if completer:
-            yield from self._get_argument_completions(completer, document)
-
     def _get_command_completions(self, text):
-        prefix_len = len(text) - len(text.lstrip())
-        content = text.strip()
+        content = text.strip().split("  ")[-1].lower().strip()
         suffix_len = len(text) - len(text.rstrip())
         return (
             Completion(
                 f"{name}{' ' * suffix_len}",
-                -len(text.lstrip()),
+                -len(content),
                 display=self.displays.get(name, ""),
                 display_meta=self.display_metas.get(name, ""),
             )
@@ -59,7 +35,7 @@ class CmdCompleter(Completer):
                     ("." not in name and "." not in text)  # root level
                     or ("." in name and "." in text)
                 )  # library level
-                and name.lower().strip().startswith(content)
+                and normalize_kw(name).startswith(normalize_kw(content))
             )
         )
 
@@ -81,6 +57,7 @@ class CmdCompleter(Completer):
 
     def get_completions(self, document, complete_event):
         """Compute suggestions."""
+        # RobotFrameworkLocalLexer().parse_doc(document)
         text = document.current_line_before_cursor
         variables, keyword, args = parse_keyword(text.strip())
         if "FOR".startswith(text):
@@ -98,7 +75,8 @@ class CmdCompleter(Completer):
                     display_meta="For-Loop over a range of numbers",
                 ),
                 Completion(
-                    "FOR    ${index}    ${var}    IN ENUMERATE    @{list}\n    Log    ${index} - ${var}n\nEND",
+                    "FOR    ${index}    ${var}    IN ENUMERATE"
+                    "    @{list}\n    Log    ${index} - ${var}n\nEND",
                     -len(text),
                     display="FOR IN ENUMERATE",
                     display_meta="For-Loop over all items in a list with index",
@@ -123,5 +101,7 @@ class CmdCompleter(Completer):
             yield from _get_style_completions(text.lower())
         elif text.startswith("*"):
             yield from self._get_resource_completions(text.lower())
-        elif keyword and not args:
-            yield from self._get_command_completions(text.lower())
+        elif keyword:
+            if not args:
+                yield from self._get_command_completions(text.lower())
+
