@@ -1,17 +1,33 @@
+import difflib
 import os
+from typing import List
 
+from prompt_toolkit.shortcuts import clear
+from prompt_toolkit.styles import merge_styles
 from robot.api import logger
 from robot.errors import ExecutionFailed, HandlerExecutionFailed
+from robot.libdocpkg.model import KeywordDoc
+from robot.libraries.BuiltIn import BuiltIn
+from robot.running.signalhandler import STOP_SIGNAL_MONITOR
 
 from .cmdcompleter import CmdCompleter
 from .globals import context
 from .prompttoolkitcmd import PromptToolkitCmd
-from .robotapp import get_robot_instance, reset_robotframework_exception
 from .robotkeyword import find_keyword, get_keywords, get_lib_keywords, run_command
-from .robotlib import get_builtin_libs, get_libs, get_libs_dict, match_libs
+from .robotlib import get_builtin_libs, get_libs, match_libs
 from .sourcelines import RobotNeedUpgrade, print_source_lines, print_test_case_lines
 from .steplistener import is_step_mode, set_step_mode
-from .styles import DEBUG_PROMPT_STYLE, get_debug_prompt_tokens, print_error, print_output
+from .styles import (
+    BASE_STYLE,
+    DEBUG_PROMPT_STYLE,
+    _get_print_style,
+    get_debug_prompt_tokens,
+    get_pygments_styles,
+    get_style_by_name,
+    print_error,
+    print_output,
+    style_from_pygments_cls,
+)
 
 HISTORY_PATH = os.environ.get("RFDEBUG_HISTORY", "~/.rfdebug_history")
 
@@ -25,8 +41,7 @@ def run_robot_command(robot_instance, command):
     try:
         result = run_command(robot_instance, command)
     except HandlerExecutionFailed as exc:
-        print_error("! Expression:", command if "\n" not in command else f"\n{command}")
-        print_error("! Handler execution error:", exc.message)
+        print_error("! FAIL:", exc.message)
     except ExecutionFailed as exc:
         print_error("! Expression:", command if "\n" not in command else f"\n{command}")
         print_error("! Execution error:", str(exc))
@@ -46,7 +61,7 @@ class DebugCmd(PromptToolkitCmd):
 
     def __init__(self, completekey="tab", stdin=None, stdout=None):
         PromptToolkitCmd.__init__(self, completekey, stdin, stdout, history_path=HISTORY_PATH)
-        self.robot = get_robot_instance()
+        self.robot = BuiltIn()
 
     def get_prompt_tokens(self, prompt_text):
         return get_debug_prompt_tokens(prompt_text)
@@ -76,39 +91,37 @@ Access https://github.com/imbus/robotframework-debug for more details.\
 
     def get_completer(self):
         """Get completer instance specified for robotframework."""
-        # commands
         commands = [
             (cmd_name, cmd_name, "DEBUG command: {0}".format(doc))
             for cmd_name, doc in self.get_helps()
         ]
 
-        # libraries
         for lib in get_libs():
             commands.append(
                 (
                     lib.name,
                     lib.name,
-                    "Library: {0} {1}".format(lib.name, lib.version),
+                    "Library: {0} {1}".format(
+                        lib.name, lib.version if hasattr(lib, "version") else ""
+                    ),
                 )
             )
 
-        # keywords
-        for keyword in get_keywords():
-            # name with library
-            name = "{0}.{1}".format(keyword["lib"], keyword["name"])
+        keywords: List[KeywordDoc] = get_keywords()
+        for keyword in keywords:
+            name = "{0}.{1}".format(keyword.parent.name, keyword.name)
             commands.append(
                 (
                     name,
-                    keyword["name"],
-                    "Keyword: {0}".format(keyword["summary"]),
+                    keyword.name,
+                    "Keyword: {0}".format(keyword.shortdoc),
                 )
             )
-            # name without library
             commands.append(
                 (
-                    keyword["name"],
-                    keyword["name"],
-                    "Keyword[{0}.]: {1}".format(keyword["lib"], keyword["summary"]),
+                    keyword.name,
+                    keyword.name,
+                    "Keyword[{0}.]: {1}".format(keyword.parent.name, keyword.shortdoc),
                 )
             )
 
@@ -121,7 +134,7 @@ Access https://github.com/imbus/robotframework-debug for more details.\
         run_robot_command(self.robot, command)
 
     def _print_lib_info(self, lib, with_source_path=False):
-        print_output("   {}".format(lib.name), lib.version)
+        print_output("   {}".format(lib.name), lib.version if hasattr(lib, "version") else "")
         if lib.doc:
             logger.console("       {}".format(lib.doc.split("\n")[0]))
         if with_source_path:
@@ -159,12 +172,11 @@ Access https://github.com/imbus/robotframework-debug for more details.\
         if not matched:
             print_error("< not found library", lib_name)
             return
-        libs = get_libs_dict()
-        for name in matched:
-            lib = libs[name]
-            print_output("< Keywords of library", name)
-            for keyword in get_lib_keywords(lib):
-                print_output("   {}\t".format(keyword["name"]), keyword["summary"])
+        for lib in matched:
+            if lib:
+                print_output("< Keywords of library", lib.name)
+                for keyword in get_lib_keywords(lib):
+                    print_output("   {}\t".format(keyword.name), keyword.shortdoc)
 
     do_k = do_keywords
 
@@ -172,7 +184,7 @@ Access https://github.com/imbus/robotframework-debug for more details.\
         """Complete keywords command."""
         if len(line.split()) == 2:
             command, lib_name = line.split()
-            return match_libs(lib_name)
+            return [lib.name for lib in match_libs(lib_name)]
         elif len(line.split()) == 1 and line.endswith(" "):
             return [_.name for _ in get_libs()]
         return []
@@ -189,9 +201,11 @@ Access https://github.com/imbus/robotframework-debug for more details.\
         if not keywords:
             print_error("< not find keyword", keyword_name)
         elif len(keywords) == 1:
-            logger.console(keywords[0]["doc"])
+            logger.console(keywords[0].doc)
         else:
-            print_error("< found {} keywords".format(len(keywords)), ", ".join(keywords))
+            print_error(
+                "< found {} keywords".format(len(keywords)), ", ".join([k.name for k in keywords])
+            )
 
     do_d = do_docs
 
@@ -270,3 +284,30 @@ Access https://github.com/imbus/robotframework-debug for more details.\
         stop = super(DebugCmd, self).onecmd(line)
         context.last_command = self.lastcmd
         return stop
+
+    def do_style(self, args):
+        """Set style of output. Usage `style    <style_name>`. Call just `style` to list all styles."""
+        styles = get_pygments_styles()
+        if not args.strip():
+            for style in styles:
+                print_output(f"> {style}    ", style, _get_print_style(style))
+            return
+        style = difflib.get_close_matches(args.strip(), styles)[0]
+        self.prompt_style = merge_styles(
+            [BASE_STYLE, style_from_pygments_cls(get_style_by_name(style))]
+        )
+        print_output("Set style to:   ", style, _get_print_style(str(style)))
+
+    def do_clear(self, args):
+        """Clear screen."""
+        clear()
+
+    do_cls = do_clear
+
+
+def reset_robotframework_exception():
+    """Resume RF after press ctrl+c during keyword running."""
+    if STOP_SIGNAL_MONITOR._signal_count:
+        STOP_SIGNAL_MONITOR._signal_count = 0
+        STOP_SIGNAL_MONITOR._running_keyword = True
+        logger.info("Reset last exception of DebugLibrary")
