@@ -2,6 +2,7 @@ import cmd
 import os
 import re
 
+from prompt_toolkit import HTML
 from prompt_toolkit.application import get_app
 from prompt_toolkit.auto_suggest import AutoSuggestFromHistory
 from prompt_toolkit.buffer import Buffer
@@ -20,112 +21,11 @@ from prompt_toolkit.lexers import PygmentsLexer
 from prompt_toolkit.output import ColorDepth
 from prompt_toolkit.shortcuts import CompleteStyle, prompt
 from pygments.lexer import Lexer
-from pygments.lexers.robotframework import (
-    ARGUMENT,
-    GHERKIN,
-    KEYWORD,
-    SEPARATOR,
-    SYNTAX,
-    RowSplitter,
-    Tokenizer,
-    VariableTokenizer,
-    _Table,
-)
+from pygments.lexers.robotframework import RobotFrameworkLexer
 
+from .lexer import RobotFrameworkLocalLexer
 from .robotkeyword import get_rprompt_text
 
-
-class KeywordCall(Tokenizer):
-    _tokens = (KEYWORD, ARGUMENT)
-    _gherkin_prefix = re.compile("^(Given|When|Then|And|But) ", re.IGNORECASE)
-
-    def __init__(self):
-        Tokenizer.__init__(self)
-        self._keyword_found = False
-        self._assigns = 0
-
-    def _tokenize(self, value, index):
-        match = self._gherkin_prefix.match(value)
-        if not self._keyword_found and match:
-            end = match.end()
-            self._keyword_found = True
-            return [(value[:end], GHERKIN), (value[end:], KEYWORD)]
-        if not self._keyword_found and self._is_assign(value):
-            self._assigns += 1
-            return SYNTAX  # VariableTokenizer tokenizes this later.
-        if self._keyword_found:
-            return Tokenizer._tokenize(self, value, index - self._assigns)
-        self._keyword_found = True
-        return [(value, KEYWORD)]
-
-
-class TestCaseTable(_Table):
-    _test_template = None
-    _default_template = None
-    _gherkin_found = False
-
-    @property
-    def _tokenizer_class(self):
-        return KeywordCall
-
-    def _continues(self, value, index):
-        return index > 0 and _Table._continues(self, value, index)
-
-    def _tokenize(self, value, index):
-        if index == 0 and self._is_empty(value):
-            return [(value, SYNTAX)]
-        return _Table._tokenize(self, value, index)
-
-
-class RowTokenizer:
-    def __init__(self):
-        self._table = TestCaseTable()
-        self._splitter = RowSplitter()
-
-    def tokenize(self, row):
-        for index, value in enumerate(self._splitter.split(row)):
-            # First value, and every second after that, is a separator.
-            index, separator = divmod(index - 1, 2)
-            yield from self._tokenize(value, index, separator)
-        self._table.end_row()
-
-    def _tokenize(self, value, index, separator):
-        if separator:
-            yield value, SEPARATOR
-        else:
-            yield from self._table.tokenize(value, index)
-
-
-class RobotFrameworkLexer(Lexer):
-    """
-    For Robot Framework test data.
-
-    Supports both space and pipe separated plain text formats.
-
-    .. versionadded:: 1.6
-    """
-
-    name = "RobotFramework"
-    url = "http://robotframework.org"
-    aliases = ["robotframework"]
-    filenames = ["*.robot", "*.resource"]
-    mimetypes = ["text/x-robotframework"]
-
-    def __init__(self, **options):
-        options["tabsize"] = 2
-        options["encoding"] = "UTF-8"
-        Lexer.__init__(self, **options)
-
-    def get_tokens_unprocessed(self, text):
-        index = 0
-        # for row in text.splitlines():
-        for value, token in RowTokenizer().tokenize(text):
-            for value, token in VariableTokenizer().tokenize(value, token):
-                if value:
-                    yield index, token, str(value)
-                    index += len(value)
-
-
 kb = KeyBindings()
 
 
@@ -196,9 +96,14 @@ def _(event):
             b.validate_and_handle()
 
 
-# shift + enter
-@kb.add("s-down", filter=~is_multiline)
-@kb.add("c-down", filter=is_multiline)
+@Condition
+def has_line_break():
+    b = get_app().current_buffer
+    return not re.search(r"\n", b.text)
+
+
+@kb.add("s-down", filter=has_line_break)
+@kb.add("c-down", filter=has_line_break)
 def _(event):
     b: Buffer = event.app.current_buffer
     b.newline()
@@ -376,8 +281,6 @@ iRobot can interpret single or multiple keyword calls,
 as well as FOR, IF, WHILE, TRY
 and resource file syntax like *** Keywords*** or *** Variables ***.
 
-Press Shift+ArrowDown to insert a new line.
-
 Type "help" for more information.\
 """
 
@@ -388,6 +291,14 @@ Type "help" for more information.\
     def prompt_continuation(self, width, line_number, is_soft_wrap):
         return " " * width
 
+    def bottom_toolbar(self):
+        return [
+            ("class:bottom-toolbar-key", "more features"),
+            ("class:bottom-toolbar", " coming soon...     "),
+            ("class:bottom-toolbar-key", "Shift+ArrowDown"),
+            ("class:bottom-toolbar", " to insert a new line."),
+        ]
+
     def get_input(self):
         kwargs = {}
         if self.get_prompt_tokens:
@@ -398,6 +309,7 @@ Type "help" for more information.\
         try:
             line = prompt(
                 auto_suggest=AutoSuggestFromHistory(),
+                bottom_toolbar=self.bottom_toolbar,
                 clipboard=PyperclipClipboard(),
                 color_depth=ColorDepth.DEPTH_24_BIT,
                 completer=self.get_completer(),
@@ -407,7 +319,7 @@ Type "help" for more information.\
                 history=self.history,
                 include_default_pygments_style=False,
                 key_bindings=kb,
-                lexer=PygmentsLexer(RobotFrameworkLexer),
+                lexer=PygmentsLexer(RobotFrameworkLocalLexer),
                 message=prompt_str,
                 mouse_support=True,
                 prompt_continuation=self.prompt_continuation,
