@@ -1,7 +1,7 @@
 from robot.libdocpkg.model import LibraryDoc
-from robot.libdocpkg.robotbuilder import KeywordDocBuilder, LibraryDocBuilder
+from robot.libdocpkg.robotbuilder import KeywordDocBuilder, LibraryDocBuilder, ResourceDocBuilder
 from robot.libraries import STDLIBS
-from robot.running.namespace import IMPORTER
+from robot.libraries.BuiltIn import BuiltIn
 
 
 def get_builtin_libs():
@@ -11,20 +11,29 @@ def get_builtin_libs():
 
 def get_libs():
     """Get imported robotframework library names."""
-    libs = [lib for lib in IMPORTER._library_cache._items if lib.name != "Reserved"]
+    libs = [
+        lib for lib in BuiltIn()._namespace._kw_store.libraries.values() if lib.name != "Reserved"
+    ]
+    resources = BuiltIn()._namespace._kw_store.resources._items
+    libs.extend(resources)
     return sorted(libs, key=lambda _: _.name)
 
 
-def get_libs_dict():
-    """Get imported robotframework libraries as a name -> lib dict"""
-    return {lib.name: lib for lib in IMPORTER._library_cache._items if lib.name != "Reserved"}
-
-
 def match_libs(name=""):
     """Find libraries by prefix of library name, default all"""
-    libs = [_.name for _ in get_libs()]
-    matched = [_ for _ in libs if _.lower().startswith(name.lower())]
-    return matched
+    return [lib for lib in get_libs() if lib.name.lower().startswith(name.lower())]
+
+
+class ImportedResourceDocBuilder(ResourceDocBuilder):
+    def build(self, resource):
+        libdoc = LibraryDoc(
+            name=resource.name,
+            doc=self._get_doc(resource, resource.name),
+            type="RESOURCE",
+            scope="GLOBAL",
+        )
+        libdoc.keywords = KeywordDocBuilder().build_keywords(resource)
+        return libdoc
 
 
 class ImportedLibraryDocBuilder(LibraryDocBuilder):
